@@ -45,26 +45,12 @@ CAMLprim value core_gc_major_collections(value unit __attribute__((unused)))
   return Val_long(caml_stat_major_collections);
 }
 
-CAMLprim value core_gc_heap_words(value unit __attribute__((unused)))
-{
-  return Val_long(caml_stat_heap_wsz);
-}
-
-CAMLprim value core_gc_heap_chunks(value unit __attribute__((unused)))
-{
-  return Val_long(caml_stat_heap_chunks);
-}
 
 CAMLprim value core_gc_compactions(value unit __attribute__((unused)))
 {
   return Val_long(caml_stat_compactions);
 }
 
-CAMLprim value core_gc_top_heap_words(value unit __attribute__((unused)))
-{
-  return Val_long(caml_stat_top_heap_wsz);
-}
-
 CAMLprim value core_gc_major_plus_minor_words(value unit __attribute__((unused)))
 {
   return Val_long(minor_words() + major_words());
@@ -74,10 +60,3 @@ CAMLprim value core_gc_allocated_words(value unit __attribute__((unused)))
 {
   return Val_long(minor_words() + major_words() - promoted_words());
 }
-
-CAMLprim value core_gc_run_memprof_callbacks(value unit __attribute__((unused)))
-{
-  value exn = caml_memprof_handle_postponed_exn();
-  caml_raise_if_exception(exn);
-  return Val_unit;
-}
